@@ -1,6 +1,8 @@
 test_that("estimate-semi-erf works as expected ", {
 
   # Weighting
+  skip_on_cran()
+  data.table::setDTthreads(1)
   set.seed(245)
   gam_model <-  estimate_semipmetric_erf(Y ~ s(w) + cf5,
                                   family = gaussian,
