@@ -1,5 +1,7 @@
 test_that("matching_l1 functions as expected.", {
 
+  skip_on_cran()
+  data.table::setDTthreads(1)
   set.seed(721)
   s_data <- generate_syn_data(sample_size=200,
                               outcome_sd = 10,
@@ -11,8 +13,7 @@ test_that("matching_l1 functions as expected.", {
   data_with_gps_test <- estimate_gps(s_data[, c("id", "w")],
                                      s_data[, c("id", "cf1", "cf2", "cf3",
                                                 "cf4","cf5", "cf6")],
-                                     sl_lib = c("SL.xgboost","SL.earth",
-                                                "SL.gam","SL.ranger")
+                                     sl_lib = c("SL.xgboost")
                             )
 
   m_d <- data_with_gps_test
@@ -33,6 +34,6 @@ test_that("matching_l1 functions as expected.", {
 
 
 
-   expect_equal(nrow(val), 6)
+   expect_equal(nrow(val), 1)
    expect_equal(length(val), 2)
 })
